#
# spec file for package kpl
#
# norootforbuild

%bcond_with debuginfo

Name:           kpl
Version:        4.1
Release:        1%{?dist}
Summary:        A Program for Graphical Presentation of Data Sets and Functions

%if 0%{?suse_version} || 0%{?sles_version}
Group:          Productivity/Scientific/Math
License:        GPL-2.0+
%else
Group:          Applications/Productivity
License:        GPLv2+
%endif
URL:            http://omnibus.uni-freiburg.de/~stille/kpl/
Source0:        http://omnibus.uni-freiburg.de/~stille/kpl/%{name}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if 0%{?suse_version} || 0%{?sles_version}
BuildRequires:  libkde4-devel update-desktop-files
%kde4_runtime_requires
%else
BuildRequires:  kdelibs-devel desktop-file-utils qca
%endif
Requires:       shared-mime-info

%description
Kpl is a program for two- and three-dimensional graphical presentation
of data sets and functions. Multidimensional nonlinear parameter fits of
functions to data sets can be performed using the Levenberg-Marquardt
algorithm. Also general linear least square parameter fits are possible.
A D-BUS interface can be used to control Kpl by other applications and
scripts.

All settings necessary for a complete description of the presentation
can be saved in plot files. These files as well as data files may be
chosen via command line parameters, using the File menu, or by drag and
drop.

Automatic scaling and normalization allow the easy graphical presentation
of data. Also parameter fits can be performed automatically.
The settings of a presentation may be changed using the Edit menu. Here
also additional data sets and functions can be included which
can be displayed in the same as well as in different data windows.

Authors:
--------
    Werner Stille <stille@uni-freiburg.de>

%package devel
Summary:        Developer Package for Kpl
%if 0%{?suse_version} || 0%{?sles_version}
Group:          Development/Libraries/KDE
%else
Group:          Development/Libraries
%endif
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use the shared library of Kpl.

Kpl is a KDE program for two- and three-dimensional graphical presentation
of data sets and functions. Multidimensional nonlinear parameter fits of
functions to data sets can be performed using the Levenberg-Marquardt
algorithm. Also general linear least square parameter fits are possible.

Authors:
--------
    Werner Stille <stille@uni-freiburg.de>

%package devel-doc
Summary:        Developer Documentation Package for Kpl
%if 0%{?suse_version} || 0%{?sles_version}
Group:          Documentation/HTML
BuildRequires:  doxygen graphviz graphviz-gd graphviz-gnome libqt4-devel-doc-data
%else
Group:          Documentation
BuildRequires:  doxygen graphviz qt-doc
%endif
BuildArch:      noarch

%description devel-doc
The %{name}-devel-doc package contains the API documentation of the shared
library of Kpl.

Kpl is a KDE program for two- and three-dimensional graphical presentation
of data sets and functions. Multidimensional nonlinear parameter fits of
functions to data sets can be performed using the Levenberg-Marquardt
algorithm. Also general linear least square parameter fits are possible.

Authors:
--------
    Werner Stille <stille@uni-freiburg.de>

%if %{with debuginfo}
%debug_package
%endif

%prep
%setup -q -n %{name}


%build
mkdir -p build
pushd build
%cmake_kde4 ..
make %{?_smp_mflags}
popd


%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} -C build
%if 0%{?suse_version} || 0%{?sles_version}
%find_lang %{name} --without-kde --all-name
%kde_post_install
%else
%find_lang %{name} --all-name
%endif


%check
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
desktop-file-validate %{buildroot}%{_datadir}/applications/kde4/kpl.desktop
%endif

%post
/sbin/ldconfig
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
touch --no-create %{_datadir}/icons/hicolor &> /dev/null || :
%endif
update-mime-database %{_datadir}/mime >/dev/null

%postun
/sbin/ldconfig
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
if [ $1 -eq 0 ] ; then
  update-desktop-database -q &> /dev/null
  touch --no-create %{_datadir}/icons/hicolor &> /dev/null
  gtk-update-icon-cache %{_datadir}/icons/hicolor &> /dev/null || :
fi
%endif
update-mime-database %{_datadir}/mime >/dev/null

%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
%posttrans
update-desktop-database -q &> /dev/null
gtk-update-icon-cache %{_datadir}/icons/hicolor &> /dev/null || :
%endif


%files -f %{name}.lang
%defattr(-,root,root)
%doc ChangeLog COPYING AUTHORS README
%{_bindir}/kpl
%{_libdir}/libkpl.so.*
%{_libdir}/kde4/plugins/kpl
%{_prefix}/share/applications/kde4/kpl.desktop
%{_datadir}/icons/*/*/actions/kpl-plot.*
%{_datadir}/icons/*/*/apps/kpl.*
%{_datadir}/icons/*/*/mimetypes/application-x-kpl-plot.*
%{_datadir}/kde4/apps/kpl
%if 0%{?suse_version} || 0%{?sles_version}
%{_datadir}/kde4/config.kcfg/kpl.kcfg
%else
%{_datadir}/config.kcfg/kpl.kcfg
%endif
%{_datadir}/dbus-1/interfaces/org.kde.Kpl.xml
%{_datadir}/dbus-1/services/org.kde.kpl.service
%{_datadir}/mime/packages/x-kpl-plot.xml
%{_kde4_docdir}/HTML/*/kpl

%files devel
%defattr(-,root,root)
%doc COPYING
%if 0%{?suse_version} || 0%{?sles_version}
%{_prefix}/include/kpl
%{_prefix}/include/kpl/*.h
%else
%{_prefix}/include/kde4/kpl
%{_prefix}/include/kde4/kpl/*.h
%endif
%{_libdir}/libkpl.so

%files devel-doc
%defattr(-,root,root)
%doc COPYING
%{_kde4_docdir}/HTML/en/kpl-apidocs


%changelog
* Sun Jun 21 2015 - Werner Stille <stille@uni-freiburg.de>
- 4.1-1
* Tue Jun 14 2011 - Werner Stille <stille@uni-freiburg.de>
- new version 4.0
