/***************************************************************************
                          arrowitem.h  -  description
                             -------------------
    begin                : Sat Apr 14 2001
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ARROWITEM_H
#define ARROWITEM_H

#include <QAbstractGraphicsShapeItem>
#include <QPolygonF>
#include "vectoritem.h"

class QTransform;

/**
  * Arrow item class. Class for arrow decoration items.
  * @author Werner Stille
  */
class KDE_EXPORT ArrowItem :
 public VectorItem, public QAbstractGraphicsShapeItem
{
public:
  /** Specific QGraphicsItem type number for function type() */
  enum {Type = UserType + Arrow
    /**< Specific QGraphicsItem type number of ArrowItem for function
     * type().
     */
  };
  /**
    * Constructor. Initializes corresponding to arguments.
    * @param x0 x position of head in cm.
    * @param y0 y position of head in cm.
    * @param color color for arrow.
    * @param parent pointer to parent item.
    * @param length total length in cm.
    * @param visible true for visible item.
    * @param doubleHeaded true for doubleheaded arrow.
    * @param relSize relative size of head.
    * @param dir direction in deg.
    */
  ArrowItem(double x0 = 0, double y0 = 0, unsigned color = 0,
            QGraphicsItem* parent = 0, double length = 1, bool visible = true,
            bool doubleHeaded = false, double relSize = 1, double dir = 0);
  /**
    * Copy constructor.
    * @param a source item.
    */
  ArrowItem(const ArrowItem& a);
  /**
    * Constructor. Initializes corresponding to plot file.
    * @param plo pointer to KSimpleConfig object containing item data.
    * @param color default color for arrow.
    * @param parent pointer to parent item.
    */
  ArrowItem(const KConfigGroup* plo, unsigned color = 0,
            QGraphicsItem* parent = 0);
  /** Destructor. */
  virtual ~ArrowItem();
  /** Calculates bounding rectangle. */
  virtual QRectF boundingRect() const;
  /** Returns true for doubleheaded arrow. */
  inline bool doubleHeaded() const { return m_doubleHeaded; };
  /** Paints item. */
  virtual void paint(QPainter* painter, const QStyleOptionGraphicsItem* option,
                     QWidget* widget = 0);
  /** Returns decoration pixmap for item list. */
  QPixmap pixmap() const;
  /**
    * Sets doubleheaded mode.
    * @param b true for doubleheaded arrow.
    */
  inline void setDoubleHeaded(bool b) { m_doubleHeaded = b; };
  /** Sets head shape. */
  void setHead();
  /** Sets pen width. */
  void setPenWidth();
  /**
    * Sets properties according to transformation matrix.
    * @param m transformation matrix.
    */
  void setProperties(const QTransform& m);
  /** Returns specific QGraphicsItem type number. */
  virtual int type() const { return Type; };
  /** Applies changes and forces redrawing. */
  void update();
  /**
   * Writes into plot file.
   * @param plo KConfigGroup object.
   */
  void writePlo(KConfigGroup* plo) const;

protected:
  /** Updates position. */
  virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent* event);
  /** Sets properties according to transformation matrix. */
  void setProperties();
  bool m_doubleHeaded;
  double l2, lHead;
  QPolygonF head;
};

#endif
