/***************************************************************************
                          decoitem.cpp  -  description
                             -------------------

    This file is a part of kpl - a program for graphical presentation of
    data sets and functions.

    begin                : Wed Aug 25 1999
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <KConfigGroup>
#include "decoitem.h"

DecoItem::DecoItem(unsigned color, double x0, double y0, double relSize) :
 KplItem(relSize), m_color(color), m_x0(x0), m_y0(y0)
{
}

DecoItem::DecoItem(const KConfigGroup* plo, unsigned col) :
 KplItem(plo)
{
  QString s = plo->readEntry("colsymb", "");
  m_color = s.isEmpty() ? col : rgb(s);
  m_x0 = plo->readEntry("x", 0.0);
  m_y0 = plo->readEntry("y", 0.0);
}

DecoItem::~DecoItem()
{
}

void DecoItem::updatePos(const QPointF& p, bool absolute)
{
  if (absolute) {
    m_x0 = p.x();
    m_y0 = p.y();
  } else {
    m_x0 += p.x();
    m_y0 += p.y();
  }
}

void DecoItem::writePlo(KConfigGroup* plo, bool visible) const
{
  KplItem::writePlo(plo, visible);
  plo->writeEntry("x", m_x0);
  plo->writeEntry("y", m_y0);
  plo->writeEntry("colsymb", QString::number(rgbQt1(m_color), 16));
}
