/***************************************************************************
                          decoitem.h  -  description
                             -------------------

    This file is a part of kpl - a program for graphical presentation of
    data sets and functions.

    begin                : Wed Aug 25 1999
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DECOITEM_H
#define DECOITEM_H

#include <kdemacros.h>
#include <QTransform>
#include "kplitem.h"

class QPointF;
class KConfigGroup;

/**
  * Decoration item class. Base class for decoration items.
  * @author Werner Stille
  */
class KDE_EXPORT DecoItem : public KplItem
{
public:
  /**
    * Constructor. Initializes corresponding to arguments.
    * @param color color for plot.
    * @param x0 x position in cm.
    * @param y0 y position in cm.
    * @param relSize relative size.
    */
  DecoItem(unsigned color = 0, double x0 = 0, double y0 = 0,
           double relSize = 1);
  /**
    * Constructor. Initializes corresponding to plot file.
    * @param plo pointer to KSimpleConfig object containing item data.
    * @param color default value for color.
    */
 DecoItem(const KConfigGroup* plo, unsigned color = 0);
  /** Destructor. */
  virtual ~DecoItem();
  /** Returns color. */
  inline unsigned color() const { return m_color; };
  /**
    * Sets color.
    * @param color color.
    */
  inline void setColor(unsigned color) { m_color = color; };
  /**
    * Sets x position.
    * @param x0 x position in cm.
    */
  inline void setX0(double x0) { m_x0 = x0; };
  /**
    * Sets y position.
    * @param y0 y position in cm.
    */
  inline void setY0(double y0) { m_y0 = y0; };
  /**
    * Updates position.
    * @param p position coordinates in cm.
    * @param absolute true for absolute position, false for position increment.
    */
  void updatePos(const QPointF& p, bool absolute = true);
  /**
   * Writes into plot file.
   * @param plo KConfigGroup object.
   * @param visible true for visible item.
   */
  void writePlo(KConfigGroup* plo, bool visible) const;
  /** Returns x position in cm. */
  inline double x0() const { return m_x0; };
  /** Returns y position in cm. */
  inline double y0() const { return m_y0; };

protected:
  unsigned m_color;
  double m_x0, m_y0;
  QTransform m_matrix;
};

#endif
