/***************************************************************************
                          lineitem.cpp  -  description
                             -------------------
    begin                : Mon Apr 16 2001
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <KConfigGroup>
#include "kplscene.h"
#include "lineitem.h"

LineItem::LineItem(double x0, double y0, unsigned color, QGraphicsItem* parent,
                   double length, bool visible, Symbol symbol, double relSize,
                   double dir) :
 VectorItem(color, x0, y0, length, dir, relSize), QGraphicsLineItem(parent),
 m_symbol(symbol)
{
  if (!visible)
    hide();
  setFlags(QGraphicsItem::ItemIsMovable | QGraphicsItem::ItemIsSelectable);
}

LineItem::LineItem(const LineItem& a) :
 VectorItem(a), QGraphicsLineItem(), m_symbol(a.m_symbol)
{
  setZValue(a.zValue());
  setFlags(QGraphicsItem::ItemIsMovable | QGraphicsItem::ItemIsSelectable);
  setSelected(a.isSelected());
  setVisible(a.isVisible());
}

LineItem::LineItem(const KConfigGroup* plo, unsigned color,
                   QGraphicsItem* parent) :
 VectorItem(plo, color), QGraphicsLineItem(parent)
{
  if (!plo->readEntry("active", true))
    hide();
  m_symbol = Symbol(plo->readEntry("symb", int(SolidLine)));
  setFlags(QGraphicsItem::ItemIsMovable | QGraphicsItem::ItemIsSelectable);
}

LineItem::~LineItem()
{
}

QPixmap LineItem::pixmap() const
{
  return KplItem::pixmap(pen(), m_symbol);
}

void LineItem::setDashOffset()
{
  if (m_symbol != 1) {
    QPen p = pen();
    p.setDashOffset(m_dashOffset);
    double s = 0;
    foreach (double d, p.dashPattern())
      s += d;
    m_dashOffset += line().length() / p.widthF();
    m_dashOffset -= int(m_dashOffset / s) * s;
    setPen(p);
  }
}

void LineItem::setPenWidth()
{
  QPen p = pen();
  double w = penWidth(this);
  if (p.widthF() != w) {
    prepareGeometryChange();
    setPen(changePenWidth(p, w));
  }
}

void LineItem::setProperties(const QTransform& m)
{
  m_matrix = m;
  setProperties();
}

void LineItem::update()
{
  prepareGeometryChange();
  setProperties();
  QGraphicsLineItem::update();
}

void LineItem::writePlo(KConfigGroup* plo) const
{
  plo->writeEntry("Type", "LINEITEM");
  VectorItem::writePlo(plo, isVisible());
  plo->writeEntry("symb", int(m_symbol));
}

void LineItem::mouseReleaseEvent(QGraphicsSceneMouseEvent* event)
{
  QGraphicsLineItem::mouseReleaseEvent(event);
  ((KplScene*)scene())->updatePos(this);
}

void LineItem::setProperties()
{
  setLine(0, 0, m_matrix.m11() * m_length, 0);
  setPos(m_matrix.map(QPointF(m_x0, m_y0)));
#if QT_VERSION < 0x040600
  setTransform(QTransform().rotate(-m_dir));
#else
  setRotation(-m_dir);
#endif
  setPen(createPen(this, m_color, DataPen, m_symbol));
}
