/***************************************************************************
                          vectoritem.h  -  description
                             -------------------

    This file is a part of kpl - a program for graphical presentation of
    data sets and functions.

    begin                : Wed Aug 25 1999
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef VECTORITEM_H
#define VECTORITEM_H

#include <kdemacros.h>
#include "decoitem.h"

class KConfigGroup;

/**
  * Vector item class. Base class for line and arrow items.
  * @author Werner Stille
  */
class KDE_EXPORT VectorItem : public DecoItem
{
public:
  /**
    * Constructor. Initializes corresponding to arguments.
    * @param color color for plot.
    * @param x0 x position in cm.
    * @param y0 y position in cm.
    * @param length length in cm.
    * @param dir rotation angle in degree.
    * @param relSize relative size.
    */
  VectorItem(unsigned color = 0, double x0 = 0, double y0 = 0,
             double length = 1, double dir = 0, double relSize = 1);
  /**
    * Constructor. Initializes corresponding to plot file.
    * @param plo pointer to KSimpleConfig object containing item data.
    * @param color color for plot.
    */
  VectorItem(const KConfigGroup* plo, unsigned color = 0);
  /** Destructor. */
  virtual ~VectorItem();
  /** Returns rotation angle in deg. */
  inline double dir() const { return m_dir; };
  /** Returns length in cm. */
  inline double length() const { return m_length; };
  /**
    * Sets rotation angle.
    * @param dir rotation angle in deg.
    */
  inline void setDir(double dir) { m_dir = dir; };
  /**
    * Sets length.
    * @param length length in cm.
    */
  inline void setLength(double length) { m_length = length; };
  /**
   * Writes into plot file.
   * @param plo KSimpleConfig object.
   * @param visible true for visible item.
   */
  void writePlo(KConfigGroup* plo, bool visible) const;

protected:
  double m_length, m_dir;
};

#endif
