/***************************************************************************
                          arrowdlg.h  -  description
                             -------------------
    begin                : Sat Apr 14 2001
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ARROWDLG_H
#define ARROWDLG_H

#include "decodlg.h"

class QCheckBox;
class ArrowItem;
class VectorItem;

/**
  * Arrow settings dialog class. Provides a dialog for the settings
  * of an arrow decoration item.
  * @author Werner Stille
  */
class ArrowDlg : public DecoDlg
{
  Q_OBJECT
public:
  /**
   * Constructor.
   * @param parent pointer to parent widget.
   * @param model pointer to KplDoc model object.
   * @param ai pointer to arrow item.
   * @param pos dialog position.
   */
  ArrowDlg(QWidget* parent, KplDoc* model, ArrowItem* ai, const QPoint& pos);
  /** Destructor. */
  ~ArrowDlg();
  /**
   * Creates direction and length entry widgets.
   * @param ad arrow item.
   * @param grid grid layout.
   * @param eDir direction widget.
   * @param eLen length widget.
   */
  static void initPolarEntries(const VectorItem* ad,
                               QGridLayout* grid, QDoubleSpinBox** eDir,
                               QDoubleSpinBox** eLen);

protected:
  /**
   * Calculates coordinates.
   * @param x pointer to x result.
   * @param y pointer to y result.
   * @param dx x component of length vector.
   * @param dy y component of length vector.
   */
  void calcCoord(double* x, double* y, double dx, double dy);
  int koord;
  ArrowItem* ai;
  QDoubleSpinBox *eDir, *eLen;
  QCheckBox* dbl;

protected slots:
  /** Reimplemented from KDialog. */
  virtual void slotButtonClicked(int button);
  /**
   * Sets x0 and y0 entries according to coordinates radiobuttons.
   * @param id button id, 0 for head, 1 for center, 2 for end.
   */
  void slotSetCoord(int id);
};

#endif
