/***************************************************************************
                          brushdlg.cpp  -  description
                             -------------------
    begin                : Mit Mai 14 2003
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <QApplication>
#include <QLayout>
#include <qstyle.h>
#include <QStyleOptionButton>
#include <QStylePainter>
#include <KButtonGroup>
#include <KLocalizedString>
#include "brushdlg.h"
#include "kplitem.h"

BrushButton::BrushButton(int brush, QWidget* parent) :
 QPushButton(parent), m_brush(brush)
{
  connect(this, SIGNAL(clicked()), SLOT(slotBrush()));
}

BrushButton::~BrushButton()
{
}

QSize BrushButton::sizeHint() const
{
  QStyleOptionButton opt;
  initStyleOption(&opt);
  return style()->sizeFromContents(QStyle::CT_PushButton, &opt, QSize(40, 20),
                                   this).
    expandedTo(QApplication::globalStrut());
}

void BrushButton::setValue(int brush)
{
  m_brush = brush;
  repaint();
}

int BrushButton::value()
{
  return m_brush;
}

void BrushButton::slotBrush()
{
  int oldBrush = m_brush;
  BrushDlg dlg(&m_brush, parentWidget());
  dlg.exec();
  if (m_brush != oldBrush)
    emit changed(m_brush);
}

void BrushButton::paintEvent(QPaintEvent*)
{
  QPainter p(this);
  QStyleOptionButton opt;
  initStyleOption(&opt);
  style()->drawControl(QStyle::CE_PushButtonBevel, &opt, &p, this);
  QRect r = style()->subElementRect(QStyle::SE_PushButtonContents, &opt, this);
  r.adjust(1, 1, -1, -2);
  if (m_brush)
    p.fillRect(r, KplItem::createBrush(0, KplItem::FillStyle(m_brush)));
  else
    p.drawRect(r);
}

BrushRadioButton::BrushRadioButton(int brush, QWidget* parent) :
 QRadioButton(parent), m_brush(brush)
{
}

BrushRadioButton::~BrushRadioButton()
{
}

void BrushRadioButton::paintEvent(QPaintEvent*)
{
  QPainter p(this);
  QStyleOptionButton opt;
  initStyleOption(&opt);
  style()->drawControl(QStyle::CE_RadioButton, &opt, &p, this);
  QRect r = style()->subElementRect(QStyle::SE_RadioButtonContents, &opt, this);
  r.adjust(1, 1, -1, -2);
  if (m_brush)
    p.fillRect(r, KplItem::createBrush(0, KplItem::FillStyle(m_brush)));
  else
    p.drawRect(r);
}

BrushDlg::BrushDlg(int* brush, QWidget* parent) :
 KDialog(parent), m_brush(brush)
{
  setCaption(i18n("Patterns"));
  setButtons(Ok | Cancel);
  QWidget* page = new QWidget;
  setMainWidget(page);
  QVBoxLayout* vbox = new QVBoxLayout(page);
  vbox->setSpacing(spacingHint());
  vbox->addWidget(bg = new KButtonGroup);
  QGridLayout* grid = new QGridLayout(bg);
  for (int i = 0; i < 8; i++)
    grid->addWidget(new BrushRadioButton(i), i % 4, i / 4);
  bg->setSelected(*m_brush);
  connect(bg, SIGNAL(changed(int)), SLOT(slotEdited()));
  setMinimumWidth(280);
  enableButtonOk(false);
}

BrushDlg::~BrushDlg()
{
}

void BrushDlg::slotButtonClicked(int button)
{
  switch (button) {
    case Ok: {
      *m_brush = bg->selected();
      accept();
    }
    default:
      KDialog::slotButtonClicked(button);
  }
}

void BrushDlg::slotEdited()
{
  enableButtonOk(true);
}
