/***************************************************************************
                          decodlg.h  -  description
                             -------------------
    begin                : Fri Apr 20 2001
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DECODLG_H
#define DECODLG_H

#include <KDialog>

class QDoubleSpinBox;
class QGridLayout;
class QLabel;
class QPoint;
class KColorButton;
class DecoItem;
class KplDoc;
class SpinBox;

/**
  * Decoration settings dialog class. Provides a base dialog for the settings
  * dialogs for text, line, and arrow decoration items.
  * @author Werner Stille
  */
class DecoDlg : public KDialog
{
  Q_OBJECT
public:
  /**
   * Constructor.
   * @param parent pointer to parent widget.
   * @param caption window caption.
   * @param anchor help anchor string.
   * @param model pointer to KplDoc model object.
   * @param it pointer to decoration item.
   * @param pos dialog position.
   */
  DecoDlg(QWidget* parent, const QString& caption, const QString& anchor,
          KplDoc* model, const DecoItem* it, const QPoint& pos);
  /** Destructor. */
  ~DecoDlg();

protected slots:
  /** Enables buttons. */
  void slotEdited();

protected:
  /**
   * Creates entry widgets.
   * @param row row index for position widgets.
   */
  void initEntries(int row);
  /**
   * Copies settings to deco item.
   * @param itNew pointer to deco item.
   */
  void getValues(DecoItem* itNew);
  KplDoc* m;
  const DecoItem* it;
  QDoubleSpinBox *ex0, *ey0;
  SpinBox* eRelSize;
  KColorButton* col;
  QGridLayout* grid;
  QLabel* lSize;
};

#endif
