/***************************************************************************
                          doubleedit.cpp  -  description
                             -------------------
    begin                : Tue Aug 15 2000
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <QValidator>
#include "doubleedit.h"

DoubleEdit::DoubleEdit(double val, char format, int prec, QWidget* parent) :
 QLineEdit(parent), frm(format)
{
  validator = new QDoubleValidator(this);
  validator->setDecimals(prec);
  setValidator(validator);
  setValue(val);
}

DoubleEdit::DoubleEdit(double val, double minVal, double maxVal, char format,
                       int prec, QWidget* parent) :
 QLineEdit(parent), frm(format)
{
  validator = new QDoubleValidator(minVal, maxVal, prec, this);
  setValidator(validator);
  setValue(val);
}

DoubleEdit::~DoubleEdit()
{
}

void DoubleEdit::setValue(double val)
{
  setText(QString::number(val, frm, validator->decimals()));
}

double DoubleEdit::value() const
{
  double val = text().toDouble();
  if (validator->bottom() || validator->top())
    val = qBound(validator->bottom(), val, validator->top());
  return val;
}

void DoubleEdit::setBottom(double bottom)
{
  validator->setBottom(bottom);
}

void DoubleEdit::focusOutEvent(QFocusEvent* e)
{
  interpret();
  QLineEdit::focusOutEvent(e);
}

void DoubleEdit::interpret()
{
  double val = value();
  setValue(val);
  emit changed(val);
}
