/***************************************************************************
                          doublespinbox.cpp  -  description
                             -------------------
    begin                : Do Apr 14 2005
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qlineedit.h>
#include <qvalidator.h>
#include "doublespinbox.h"

DoubleSpinBox::DoubleSpinBox(double value, double step, QWidget* parent,
                             char format, int precision) :
 QSpinBox(parent), m_format(format), m_precision(precision)
{
  setSingleStep(step, value);
}

DoubleSpinBox::DoubleSpinBox(double value, double step, double minVal,
                             double maxVal, QWidget* parent, char format,
                             int precision) :
 QSpinBox(parent), m_format(format), m_precision(precision)
{
  setRange(qRound(minVal / step), qRound(maxVal / step));
  init(value, step);
}

DoubleSpinBox::~DoubleSpinBox()
{
}

void DoubleSpinBox::setSingleStep(double step)
{
  setSingleStep(step, value());
}

double DoubleSpinBox::value() const
{
  return text().toDouble();
}

void DoubleSpinBox::init(double value, double step)
{
  m_step = QString::number(step, 'g', 2).toDouble();
  lineEdit()->setValidator(new QDoubleValidator(minimum() * m_step,
                                                maximum() * m_step,
                                                m_precision, this));
  QSpinBox::setValue(qRound(value / m_step));
}

void DoubleSpinBox::setSingleStep(double step, double value)
{
  int iVal = qRound(value / step);
  setRange(iVal - 1000000000, iVal + 1000000000);
  init(value, step);
}

QString DoubleSpinBox::textFromValue(int value) const
{
  return QString::number(value * m_step, m_format, m_precision);
}

QValidator::State DoubleSpinBox::validate(QString& text, int& pos) const
{
  return lineEdit()->validator()->validate(text, pos);
}

int DoubleSpinBox::valueFromText(const QString& text) const
{
  return qRound(text.toDouble() / m_step);
}
