/***************************************************************************
                          doublespinbox.h  -  description
                             -------------------
    begin                : Do Apr 14 2005
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DOUBLESPINBOX_H
#define DOUBLESPINBOX_H

#include <QSpinBox>

/**
  * Double value spinbox class. Provides a double value mapped QSpinBox widget
  * with validator.
  * @author Werner Stille
  */

class DoubleSpinBox : public QSpinBox
{
  Q_OBJECT
public:
  /**
   * Constructor.
   * @param value initial double value.
   * @param step step size.
   * @param parent pointer to parent widget.
   * @param format format character for value display.
   * @param precision precision (number of digits) for value display.
   */
  DoubleSpinBox(double value, double step, QWidget* parent = 0,
                char format = 'g', int precision = 6);
  /**
   * Constructor.
   * @param value initial double value.
   * @param step step size.
   * @param minVal minimum value.
   * @param maxVal maximum value.
   * @param parent pointer to parent widget.
   * @param format format character for value display.
   * @param precision precision (number of digits) for value display.
   */
  DoubleSpinBox(double value, double step, double minVal, double maxVal,
                QWidget* parent = 0, char format = 'f', int precision = 2);
  /** Destructor. */
  ~DoubleSpinBox();
  /**
   * Returns value.
   * @return value.
   */
  double value() const;

public slots:
  /**
   * Sets step size.
   * @param step step size.
   */
  void setSingleStep(double step);

protected:
  /**
   * Initializes several elements.
   * @param value initial double value.
   * @param step step size.
   */
  void init(double value, double step);
  /**
   * Sets step size.
   * @param step step size.
   * @param value current double value.
   */
  void setSingleStep(double step, double value);
  /** Returns double value string corresponding to integer value. */
  virtual QString textFromValue(int value) const;
  /** Validates input. */
  virtual QValidator::State validate(QString& text, int& pos) const;
  /** Returns integer value corresponding to double value input. */
  virtual int valueFromText(const QString& text) const;
  char m_format;
  int m_precision;
  double m_step;
};

#endif
