/***************************************************************************
                          editparameterdlg.cpp  -  description
                             -------------------
    begin                : Mit Jul 23 2003
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <QFileInfo>
#include <QGroupBox>
#include <QLabel>
#include <QLayout>
#include <QTimer>
#include <KLocalizedString>
#include "doubleedit.h"
#include "editparameterdlg.h"
#include "funitem.h"
#include "kpldoc.h"
#include "kplsettings.h"
#include "sourcewidget.h"

EditParameterDlg::EditParameterDlg(QWidget* parent, double* p0,
                                   const QString& file, const QString& func0,
                                   bool applyButton) :
 KDialog(parent), p(p0), func(func0), sw(0)
{
  setCaption(i18n("Parameters"));
  setButtons(applyButton ? Ok | Cancel | Apply : Ok | Cancel);
  setButtonFocus(Ok);
  QWidget* page = new QWidget;
  setMainWidget(page);
  QHBoxLayout* hbox = 0;
  QVBoxLayout* vbox;
  if (KplSettings::showSource()) {
    hbox = new QHBoxLayout(page);
    hbox->setSpacing(spacingHint());
    hbox->addLayout(vbox = new QVBoxLayout);
  } else {
    vbox = new QVBoxLayout(page);
    vbox->setSpacing(spacingHint());
  }
  QGroupBox* g = new QGroupBox;
  QGridLayout* grid = new QGridLayout;
  g->setLayout(grid);
  vbox->addWidget(g);
  char format = KplDoc::presentation();
  int prec = KplSettings::precision();
  int w = 0;
  for (int i = 0; i < FunItem::NumParMax; i++) {
    int ix = 3 * (i / 10);
    int iy = i % 10;
    grid->addWidget(new QLabel(QString("p%1").arg(i)), iy, ix);
    grid->addWidget(par[i] = new DoubleEdit(p[i], format, prec), iy,
                    ix + 1);
    if (!i)
      w = par[0]->fontMetrics().width(QString::number(-1e-123 / 3,
                                                      format, prec + 1)) + 3;
    par[i]->setMinimumWidth(w);
    connect(par[i], SIGNAL(textEdited(const QString&)), SLOT(slotEdited()));
  }
  for (int i = 0; i < ((FunItem::NumParMax - 1) / 10); i++)
    grid->addItem(new QSpacerItem(20, 10), 0, 3 * i + 2);
  if (KplSettings::showSource()) {
    QFileInfo fi(file);
    QString s = fi.absolutePath() + "/" + fi.baseName();
    QFile f(s + ".c");
    bool open = f.open(QIODevice::ReadOnly);
    if (!open) {
      f.setFileName(s + ".cpp");
      open = f.open(QIODevice::ReadOnly);
    }
    if (open) {
      sw = new SourceWidget(&f, page);
      hbox->addWidget(sw, 1);
      sw->setMinimumWidth(400);
      QTimer::singleShot(0, this, SLOT(highlight()));
    }
  }
  enableButtonApply(false);
  enableButtonOk(false);
}

EditParameterDlg::~EditParameterDlg()
{
}

void EditParameterDlg::highlight()
{
  sw->highlight(func);
}

void EditParameterDlg::slotButtonClicked(int button)
{
  switch (button) {
    case Apply:
      enableButtonApply(false);
      enableButtonOk(false);
    case Ok:
      for (int i = 0; i < FunItem::NumParMax; i++)
        p[i] = par[i]->value();
      if (button == Ok)
        accept();
    default:
      KDialog::slotButtonClicked(button);
  }
}

void EditParameterDlg::slotEdited()
{
  enableButtonApply(true);
  enableButtonOk(true);
}
