/***************************************************************************
                          edittextdlg.cpp  -  description
                             -------------------

    This file is a part of kpl - a program for graphical presentation of
    data sets and functions.

    begin                : Sun Apr 25 1999
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <QKeyEvent>
#include <QLayout>
#include <QPainter>
#include <QLineEdit>
#include <QRadioButton>
#include <QTextFrame>
#include <QToolButton>
#include <KButtonGroup>
#include <KLocalizedString>
#include <KPushButton>
#include <KSharedConfig>
#include <KToolInvocation>
#include "edittextdlg.h"
#include "textitem.h"

Preview::Preview(QWidget* parent) : QWidget(parent)
{
  setAutoFillBackground(true);
  setBackgroundRole(QPalette::Base);
  QFont f("Helvetica");
  f.setPixelSize(20);
  m_doc.setDefaultFont(f);
}

Preview::~Preview()
{
}

void Preview::setText(const QString& s)
{
  TextItem::setText(m_doc, s);
  QTextFrameFormat tf = m_doc.rootFrame()->frameFormat();
  tf.setMargin(8);
  m_doc.rootFrame()->setFrameFormat(tf);
  update();
}

void Preview::paintEvent(QPaintEvent*)
{
  QPainter painter(this);
  double f = height() / 40;
  painter.scale(f, f);
  m_doc.drawContents(&painter);
}

EditTextDlg::EditTextDlg(QWidget* parent, QLineEdit* e) :
 KDialog(parent), sfont("#NN"), ed(e)
{
  restoreDialogSize(KGlobal::config()->group("EditTextDlg"));
  setCaption(i18n("Edit text"));
  setButtons(None);
  QWidget* page = new QWidget;
  setMainWidget(page);
  QVBoxLayout* vbox = new QVBoxLayout(page);
  vbox->setSpacing(spacingHint());
  vbox->addWidget(editPreview = new Preview);
  editPreview->setMinimumHeight(40);
  editPreview->setText(ed->text());
  QGridLayout* grid = new QGridLayout;
  vbox->addLayout(grid);
  grid->addWidget(text = new QLineEdit(ed->text()), 0, 0);
  text->setCursorPosition(ed->text().size());
  connect(text, SIGNAL(textChanged(const QString&)),
          editPreview, SLOT(setText(const QString&)));
  connect(text, SIGNAL(textChanged(const QString&)), SLOT(slotEdited()));
  QHBoxLayout* hbox = new QHBoxLayout;
  grid->addLayout(hbox, 0, 1);
  bCat = new QToolButton;
  bCat->setArrowType(Qt::LeftArrow);
  hbox->addWidget(bCat);
  connect(bCat, SIGNAL(clicked()), SLOT(slotCat()));
  hbox->addWidget(font = new QLineEdit(sfont));
  font->setFixedWidth(60);
  KButtonGroup* bg = new KButtonGroup;
  bg->setTitle(i18n("Font"));
  grid->addWidget(bg, 1, 0);
  vbox = new QVBoxLayout(bg);
  vbox->addWidget(new QRadioButton("Helvetica"));
  vbox->addWidget(new QRadioButton("Helvetica Bold"));
  vbox->addWidget(new QRadioButton("Helvetica Italic"));
  vbox->addWidget(new QRadioButton("Helvetica Bold Italic"));
  vbox->addWidget(new QRadioButton("Symbol"));
  vbox->addWidget(new QRadioButton("Dingbats"));
  bg->setSelected(0);
  connect(bg, SIGNAL(changed(int)), SLOT(slotFont(int)));
  grid->addLayout(vbox = new QVBoxLayout, 1, 1);
  vbox->addWidget(bg = new KButtonGroup);
  bg->setTitle(i18n("Position"));
  QVBoxLayout* vbox2 = new QVBoxLayout(bg);
  vbox2->addWidget(new QRadioButton(i18n("Up")));
  vbox2->addWidget(new QRadioButton(i18n("Normal")));
  vbox2->addWidget(new QRadioButton(i18n("Down")));
  bg->setSelected(1);
  connect(bg, SIGNAL(changed(int)), SLOT(slotPos(int)));
  vbox->addWidget(ok = new KPushButton(KStandardGuiItem::ok()));
  ok->setDefault(true);
  connect(ok, SIGNAL(clicked()), SLOT(slotOk()));
  ok->setEnabled(false);
  KPushButton* b2;
  vbox->addWidget(b2 = new KPushButton(KStandardGuiItem::cancel()));
  connect(b2, SIGNAL(clicked()), SLOT(reject()));
  vbox->addWidget(help = new KPushButton(KStandardGuiItem::help()));
  connect(help, SIGNAL(clicked()), SLOT(slotHelp()));
  text->setFocus();
}

EditTextDlg::~EditTextDlg()
{
  KConfigGroup config = KGlobal::config()->group("EditTextDlg");
  saveDialogSize(config);
}

void EditTextDlg::editText(QWidget* parent, QLineEdit* ed)
{
  EditTextDlg dlg(parent, ed);
  dlg.exec();
}

void EditTextDlg::keyPressEvent(QKeyEvent* e)
{
  if ((e->QInputEvent::modifiers() == Qt::NoModifier) &&
      (e->key() == Qt::Key_F1)) {
       help->animateClick();
       e->accept();
  } else
    KDialog::keyPressEvent(e);
}

void EditTextDlg::slotCat()
{
  text->insert(font->text());
  text->setFocus();
}

void EditTextDlg::slotEdited()
{
  ok->setEnabled(true);
}

void EditTextDlg::slotFont(int id)
{
  const char fs[] = "HBOISZ";
  sfont[1] = fs[id];
  font->setText(sfont);
  bCat->setFocus();
}

void EditTextDlg::slotPos(int id)
{
  const char ps[] = "UND";
  sfont[2] = ps[id];
  font->setText(sfont);
  bCat->setFocus();
}

void EditTextDlg::slotOk()
{
  ed->setText(text->text());
  accept();
}

void EditTextDlg::slotHelp()
{
  KToolInvocation::invokeHelp("SEC-EDIT-TEXT");
}
