/***************************************************************************
                          ellipsedlg.cpp  -  description
                             -------------------

    This file is a part of kpl - a program for graphical presentation of
    data sets and functions.

    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <QCheckBox>
#include <QDoubleSpinBox>
#include <QLabel>
#include <QLayout>
#include <KLocalizedString>
#include <KUndoStack>
#include "brushdlg.h"
#include "kpldoc.h"
#include "ellipseitem.h"
#include "ellipsedlg.h"
#include "spinbox.h"

EllipseDlg::EllipseDlg(QWidget* parent, KplDoc* model, EllipseItem* ei0,
                       const QPoint& pos) :
 DecoDlg(parent, i18n("Ellipse"), "SEC-RECT", model, ei0, pos), ei(ei0)
{
  grid->addWidget(new QLabel(i18n("Width")), 0, 0);
  grid->addWidget(eWidth = new QDoubleSpinBox, 0, 1);
  eWidth->setRange(0.01, 200);
  eWidth->setSingleStep(0.1);
  eWidth->setSuffix(" cm");
  eWidth->setValue(ei->width());
  connect(eWidth, SIGNAL(valueChanged(const QString&)), SLOT(slotAspect()));
  grid->addWidget(new QLabel(i18n("Height")), 0, 3);
  grid->addWidget(eHeight = new QDoubleSpinBox, 0, 4);
  eHeight->setRange(0.01, 200);
  eHeight->setSingleStep(0.1);
  eHeight->setSuffix(" cm");
  eHeight->setValue(ei->height());
  grid->addWidget(isotropic = new QCheckBox(i18n("Circle")), 1, 1, 1, 5);
  connect(isotropic, SIGNAL(toggled(bool)), SLOT(slotAspect()));
  isotropic->setChecked(ei->width() == ei->height());
  grid->addWidget(new QLabel(i18n("Rotation")), 2, 0);
  grid->addWidget(eDir = new QDoubleSpinBox, 2, 1);
  eDir->setRange(-360, 360);
  eDir->setSuffix("\260");
  eDir->setValue(ei->dir());
  initEntries(3);
  eRelSize->setDisabled(ei->fillStyle());
  lSize->setText(i18n("Line width"));
  grid->addWidget(new QLabel(i18n("Fill pattern")), 5, 3);
  grid->addWidget(fill = new BrushButton(ei->fillStyle()), 5, 4);
  connect(fill, SIGNAL(changed(int)), SLOT(slotFillChanged(int)));
  connect(eHeight, SIGNAL(valueChanged(const QString&)), SLOT(slotEdited()));
  connect(eDir, SIGNAL(valueChanged(const QString&)), SLOT(slotEdited()));
}

EllipseDlg::~EllipseDlg()
{
}

void EllipseDlg::slotAspect()
{
  bool iso = isotropic->isChecked();
  if (iso)
    eHeight->setValue(eWidth->value());
  eHeight->setDisabled(iso);
  slotEdited();
}

void EllipseDlg::slotButtonClicked(int button)
{
  switch (button) {
    case Apply:
      enableButtonApply(false);
      enableButtonOk(false);
    case Ok: {
      EllipseItem* riNew = new EllipseItem(*ei);
      getValues(riNew);
      double w = eWidth->value();
      riNew->setWidth(w);
      riNew->setHeight(isotropic->isChecked() ? w : eHeight->value());
      riNew->setDir(eDir->value());
      riNew->setFillStyle(KplItem::FillStyle(fill->value()));
      m->undoStack()->push(new EditCommand(riNew, ei, m));
      ei = riNew;
      if (button == Ok)
        accept();
      break;
    }
    default:
      KDialog::slotButtonClicked(button);
  }
}

void EllipseDlg::slotFillChanged(int brush)
{
  eRelSize->setDisabled(brush);
  slotEdited();
}
