/***************************************************************************
                          errmoddlg.cpp  -  description
                             -------------------
    begin                : Tue May 25 1999
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <QLabel>
#include <QLayout>
#include <QLibrary>
#include <QPushButton>
#include <QRadioButton>
#include <KApplication>
#include <KButtonGroup>
#include <KLocalizedString>
#include <KUrlRequester>
#include "choosefuncdlg.h"
#include "doubleedit.h"
#include "editparameterdlg.h"
#include "errmoddlg.h"
#include "funcdlg.h"
#include "kpldoc.h"
#include "kplsettings.h"

ErrModDlg::ErrModDlg(QWidget* parent, KplDoc* model,
                     FunItem::DataErrorStruct* err0) :
 KDialog(parent),
 m(model), err(err0)
{
  errt = new FunItem::DataErrorStruct(*err);
  setCaption(i18n("Error model function"));
  setButtons(Help | Ok | Cancel);
  setButtonFocus(Ok);
  QWidget* page = new QWidget;
  setMainWidget(page);
  QGridLayout* grid = new QGridLayout(page);
  grid->addWidget(new QLabel(i18n("Library")), 0, 0);
  grid->setSpacing(spacingHint());
  grid->addWidget(fileName = new KUrlRequester(err->errModPath), 0, 1);
#if KDE_VERSION >= 0x040300
  fileName->setStartDir(KplSettings::currentDir());
#endif
  fileName->setFilter("*.so\n*");
  fileName->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
  grid->addWidget(new QLabel(i18n("Function")), 1, 0);
  QHBoxLayout* hbox = new QHBoxLayout;
  grid->addLayout(hbox, 1, 1);
  hbox->addWidget(func = new QLineEdit(err->errModName));
  KPushButton* tb = new KPushButton("...");
  tb->setFixedSize(fileName->button()->size());
  hbox->addWidget(tb);
  connect(tb, SIGNAL(clicked()), SLOT(slotFunc()));
  grid->addWidget(new QLabel(i18n("Parameter")), 2, 0);
  grid->addLayout(hbox = new QHBoxLayout, 2, 1);
  QPushButton* b;
  hbox->addWidget(b = new QPushButton(i18n("Edit")));
  connect(b, SIGNAL(clicked()), SLOT(slotEditParameter()));
  hbox->addWidget(b = new QPushButton(i18n("Load")));
  connect(b, SIGNAL(clicked()), SLOT(slotGetParameter()));
  hbox->addWidget(b = new QPushButton(i18n("Save")));
  connect(b, SIGNAL(clicked()), SLOT(slotSaveParameter()));
  grid->addWidget(new QLabel(i18n("Argument")), 3, 0);
  grid->addWidget(bg = new KButtonGroup, 3, 1, 1, 3);
  bg->setFlat(true);
  hbox = new QHBoxLayout(bg);
  hbox->addWidget(new QRadioButton(i18n("x column")));
  hbox->addWidget(new QRadioButton(i18n("y column")));
  bg->setSelected(err->errModArg);
  hbox->addItem(new QSpacerItem(20, 10, QSizePolicy::Expanding));
  setHelp("ERRORMODEL");
  enableButtonOk(false);
  connect(fileName, SIGNAL(textChanged(const QString&)), SLOT(slotEdited()));
  connect(func, SIGNAL(textChanged(const QString&)), SLOT(slotEdited()));
  connect(bg, SIGNAL(changed(int)), SLOT(slotEdited()));
}

ErrModDlg::~ErrModDlg()
{
  delete errt;
}

void ErrModDlg::slotButtonClicked(int button)
{
  switch (button) {
    case Ok: {
      errt->errModPath = fileName->url().path();
      errt->errModName = func->text();
      errt->errModArg = FunItem::DataErrorStruct::ErrorModelArgument(bg->selected());
      QLibrary* lib;
      double (*fkt)(double, const double *);
      if (!FunItem::getFuncAddr(errt->errModPath, errt->errModName, &lib,
                                &fkt))
        return;
      lib->unload();
      delete lib;
      *err = *errt;
      accept();
      break;
    }
    default:
      KDialog::slotButtonClicked(button);
  }
}

void ErrModDlg::slotEdited()
{
  enableButtonOk(true);
}

void ErrModDlg::slotEditParameter()
{
  EditParameterDlg dlg(this, errt->parErrMod, fileName->url().path(),
                       func->text());
  if (dlg.exec())
    slotEdited();
}

void ErrModDlg::slotFunc()
{
  FuncDlg::getFunc(this, fileName->url(), func);
}

void ErrModDlg::slotGetParameter()
{
  if (m->getPar(this, errt->parErrMod))
    slotEdited();
}

void ErrModDlg::slotSaveParameter()
{
  m->saveFunPar(this, errt->parErrMod);
}
