/***************************************************************************
                          legenddlg.h  -  description
                             -------------------

    This file is a part of kpl - a program for graphical presentation of
    data sets and functions.

    begin                : Sun Apr 25 1999
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef LEGENDDLG_H
#define LEGENDDLG_H

#include <KDialog>

class QDoubleSpinBox;
class QLineEdit;
class KColorButton;
class DoubleEdit;
class LegendItem;
class KplDoc;
class SpinBox;

/**
  * Legend settings dialog class. Provides a dialog for the settings
  * of a legend describing markers or lines.
  * @author Werner Stille
  */
class LegendDlg : public KDialog
{
  Q_OBJECT
public:
  /**
   * Constructor.
   * @param parent pointer to parent widget.
   * @param model pointer to KplDoc model object.
   * @param li pointer to legend object.
   * @param pos dialog position.
   */
  LegendDlg(QWidget* parent, KplDoc* model, LegendItem* li, const QPoint& pos);
  /** Destructor. */
  virtual ~LegendDlg();

protected:
  KplDoc* m;
  LegendItem* li;
  QDoubleSpinBox *ex0, *ey0, *exl, *eyl;
  QLineEdit* eText;
  SpinBox *symb, *eRelSize, *eSymbSize;
  KColorButton *colSymb, *colText;

protected slots:
  /** Reimplemented from KDialog. */
  virtual void slotButtonClicked(int button);
  /** Enables buttons. */
  void slotEdited();
  /** Displays dialog to edit text. */
  void slotEditText();
};

#endif
