/***************************************************************************
                          refreshdlg.h  -  description
                             -------------------

    This file is a part of kpl - a program for graphical presentation of
    data sets and functions.

    begin                : Sun Apr 25 1999
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <QCheckBox>
#include <QLabel>
#include <QLayout>
#include <QTimer>
#include <KLocalizedString>
#include "spinbox.h"
#include "refreshdlg.h"

RefreshDlg::RefreshDlg(QWidget* parent, QTimer* t) : KDialog(parent), timer(t)
{
  setPlainCaption(i18n("Reload periodically"));
  setButtons(Ok | Cancel);
  setButtonFocus(Ok);
  QWidget* page = new QWidget;
  setMainWidget(page);
  QHBoxLayout* hbox = new QHBoxLayout(page);
  hbox->setSpacing(spacingHint());
  hbox->addWidget(new QLabel(i18n("Interval")));
  hbox->addWidget(dt = new SpinBox(timer->interval() / 1000, 1, 600));
  dt->setSuffix(" s");
  bool b = timer->isActive();
  dt->setEnabled(b);
  hbox->addWidget(activate = new QCheckBox(i18n("Activate")));
  activate->setChecked(b);
  connect(activate, SIGNAL(toggled(bool)), dt, SLOT(setEnabled(bool)));
}

RefreshDlg::~RefreshDlg()
{
}

void RefreshDlg::slotButtonClicked(int button)
{
  switch (button) {
    case Ok:
      timer->setInterval(1000 * dt->value());
      if (activate->isChecked())
        timer->start();
      else
        timer->stop();
      accept();
      break;
    default:
      KDialog::slotButtonClicked(button);
  }
}
