/***************************************************************************
                          scalebardlg.cpp  -  description
                             -------------------
    begin                : Sam Jun 14 2003
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <QDoubleSpinBox>
#include <QLabel>
#include <QLayout>
#include <QLineEdit>
#include <QRadioButton>
#include <QToolButton>
#include <KButtonGroup>
#include <KLocalizedString>
#include <KUndoStack>
#include "edittextdlg.h"
#include "kpldoc.h"
#include "scalebardlg.h"
#include "scalebaritem.h"

ScaleBarDlg::ScaleBarDlg(QWidget* parent, KplDoc* model, ScaleBarItem* si0,
                         const QPoint& pos) :
 DecoDlg(parent, i18n("Scale Bar"), "SEC-SCALEBAR", model, si0, pos), si(si0)
{
  grid->addWidget(new QLabel(i18n("Orientation")), 0, 0);
  grid->addWidget(bg = new KButtonGroup, 0, 1, 1, 5);
  bg->setFlat(true);
  QHBoxLayout* hbox = new QHBoxLayout(bg);
  hbox->addWidget(new QRadioButton(i18n("Horizontal")));
  hbox->addWidget(new QRadioButton(i18n("Vertical")));
  bg->setSelected(si->vertical() ? 1 : 0);
  hbox->addItem(new QSpacerItem(10, 10, QSizePolicy::Expanding));
  grid->addWidget(new QLabel(i18n("Text")), 1, 0);
  grid->addLayout(hbox = new QHBoxLayout, 1, 1, 1, 4);
  hbox->addWidget(eText = new QLineEdit(si->text()));
  QToolButton* tb = new QToolButton;
  tb->setText("...");
  hbox->addWidget(tb);
  connect(tb, SIGNAL(clicked()), SLOT(slotEditText()));
  grid->addWidget(new QLabel(i18n("Length")), 2, 0);
  grid->addWidget(eLen = new QDoubleSpinBox, 2, 1);
  eLen->setMaximum(200);
  eLen->setSingleStep(0.1);
  eLen->setSuffix(" cm");
  eLen->setValue(si->length());
  initEntries(3);
  connect(bg, SIGNAL(changed(int)), SLOT(slotEdited()));
  connect(eLen, SIGNAL(valueChanged(const QString&)), SLOT(slotEdited()));
  connect(eText, SIGNAL(textChanged(const QString&)), SLOT(slotEdited()));
}

ScaleBarDlg::~ScaleBarDlg()
{
}

void ScaleBarDlg::slotButtonClicked(int button)
{
  switch (button) {
    case Apply:
      enableButtonApply(false);
      enableButtonOk(false);
    case Ok: {
      ScaleBarItem* siNew = new ScaleBarItem(*si);
      getValues(siNew);
      siNew->setVertical(bg->selected());
      siNew->setText(eText->text());
      siNew->setLength(eLen->value());
      m->undoStack()->push(new EditCommand(siNew, si, m));
      si = siNew;
      if (button == Ok)
        accept();
      break;
    }
    default:
      KDialog::slotButtonClicked(button);
  }
}

void ScaleBarDlg::slotEditText()
{
  EditTextDlg dlg(this, eText);
  dlg.exec();
  setButtonFocus(Ok);
}
