/***************************************************************************
                          textdlg.cpp  -  description
                             -------------------
    begin                : Wed Apr 18 2001
    copyright            : (C) 2015 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <QComboBox>
#include <QDoubleSpinBox>
#include <QLabel>
#include <QLayout>
#include <QLineEdit>
#include <QStringList>
#include <QToolButton>
#include <KLocalizedString>
#include <KUndoStack>
#include "edittextdlg.h"
#include "kpldoc.h"
#include "textdlg.h"
#include "textitem.h"

TextDlg::TextDlg(QWidget* parent, KplDoc* model, TextItem* td0,
                 const QPoint& pos) :
 DecoDlg(parent, i18n("Text"), "SEC-TEXT", model, td0, pos), ti(td0)
{
  grid->addWidget(new QLabel(i18n("Text")), 0, 0);
  QHBoxLayout* hbox;
  grid->addLayout(hbox = new QHBoxLayout, 0, 1, 1, 4);
  hbox->addWidget(eText = new QLineEdit(ti->text()));
  QToolButton* tb = new QToolButton;
  tb->setText("...");
  hbox->addWidget(tb);
  connect(tb, SIGNAL(clicked()), SLOT(slotEditText()));
  grid->addWidget(new QLabel(i18n("Direction")), 1, 0);
  grid->addWidget(eDir = new QDoubleSpinBox, 1, 1);
  eDir->setRange(-360, 360);
  eDir->setSuffix("\260");
  eDir->setValue(ti->dir());
  grid->addWidget(new QLabel(i18n("Alignment")), 1, 3);
  grid->addWidget(eAlign = new QComboBox, 1, 4);
  eAlign->addItems(QStringList() << i18n("left") << i18n("centered")
                                 << i18n("right"));
  eAlign->setCurrentIndex(ti->alignment() - 1);
  initEntries(2);
  connect(eDir, SIGNAL(valueChanged(const QString&)), SLOT(slotEdited()));
  connect(eAlign, SIGNAL(currentIndexChanged(int)), SLOT(slotEdited()));
  connect(eText, SIGNAL(textChanged(const QString&)), SLOT(slotEdited()));
}

TextDlg::~TextDlg()
{
}

void TextDlg::slotButtonClicked(int button)
{
  switch (button) {
    case Apply:
      enableButtonApply(false);
      enableButtonOk(false);
    case Ok: {
      TextItem* tiNew = new TextItem(*ti);
      getValues(tiNew);
      tiNew->setAlignment(TextItem::Alignment(eAlign->currentIndex() + 1));
      tiNew->setDir(eDir->value());
      tiNew->setText(eText->text());
      m->undoStack()->push(new EditCommand(tiNew, ti, m));
      ti = tiNew;
      if (button == Ok)
        accept();
      break;
    }
    default:
      KDialog::slotButtonClicked(button);
  }
}

void TextDlg::slotEditText()
{
  EditTextDlg dlg(this, eText);
  dlg.exec();
  setButtonFocus(Ok);
}
